@@ -19,7 +19,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.  
 */
 
-#include "Basic_utils.h"
+#include "Basic_utils_local.h"
 #include "RandomFieldsUtils.h"
 #include "General_utils.h"
 #include "zzz_RandomFieldsUtils.h"
